@@ -1,4 +1,6 @@
 
+from gzip import GzipFile
+from io import BytesIO
 from os.path import join
 from tempfile import mkdtemp
 import pytz
@@ -6,7 +8,7 @@ from pytest import raises
 from collections import OrderedDict
 from datetime import datetime, date, time, timedelta
 from .test_class import MyTestCls, CustomEncodeCls
-from .nonp import strip_comments, dump, dumps, load, loads, DuplicateJsonKeyException
+from .nonp import strip_comments, dump, dumps, load, loads, DuplicateJsonKeyException, is_py3, ENCODING
 from math import pi
 
 
@@ -32,6 +34,9 @@ def test_file_handle_nonumpy():
 	with open(path, 'rb') as fh:
 		data2 = load(fh, decompression=True)
 	assert data2 == nonpdata
+	with open(path, 'rb') as fh:
+		data3 = load(fh, decompression=None)  # test autodetect gzip
+	assert data3 == nonpdata
 
 
 def test_file_path_nonumpy():
@@ -39,6 +44,8 @@ def test_file_path_nonumpy():
 	dump(nonpdata, path, compression=6)
 	data2 = load(path, decompression=True)
 	assert data2 == nonpdata
+	data3 = load(path, decompression=None)  # autodetect gzip
+	assert data3 == nonpdata
 
 
 test_json_with_comments = """{ # "comment 1
@@ -79,6 +86,31 @@ ordered_map = OrderedDict((
 ))
 
 
+def test_string_compression():
+	json = dumps(ordered_map, compression=3)
+	assert json[:2] == b'\x1f\x8b'
+	data2 = loads(json, decompression=True)
+	assert ordered_map == data2
+	data3 = loads(json, decompression=None)
+	assert ordered_map == data3
+
+
+def test_compression_with_comments():
+	sh = BytesIO()
+	if is_py3:
+		test_json = bytes(test_json_with_comments, encoding=ENCODING)
+	else:
+		test_json = test_json_with_comments
+	with GzipFile(mode='wb', fileobj=sh, compresslevel=9) as zh:
+		zh.write(test_json)
+	json = sh.getvalue()
+	ref = loads(test_json_without_comments)
+	data2 = loads(json, decompression=True)
+	assert ref == data2
+	data3 = loads(json, decompression=None)
+	assert ref == data3
+
+
 def test_order():
 	json = dumps(ordered_map)
 	data2 = loads(json, preserve_order=True)
